@@ -1,6 +1,6 @@
 # flake8: noqa F401
 # Internal API re-exports
-from .dp_object import BEObjectRef, Blob, Run, Script, Variable
+from .dp_object import BEObjectRef, Blob, Run, Schedule, Script, Variable
 from .report import Blocks, File, Markdown, Plot, Report, Table
 from .runtime import Params, Result, by_datapane, on_datapane, _reset_runtime, _report
 from .common import HTTPError, IncompatibleVersionException, Resource, check_login
